Change log of rezbuild
======================

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com),
and this project adheres to
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Version 0.1.0 (June 20th, 2021)
-------------------------------
Added:
   - Initial version
